<?php

namespace IQBall\App\Controller;

use IQBall\App\Session\MutableSessionHandle;
use IQBall\App\Session\SessionHandle;
use IQBall\App\ViewHttpResponse;
use IQBall\Core\Http\HttpResponse;
use IQBall\Core\Model\TacticModel;

class UserController {
    private TacticModel $tactics;

    /**
     * @param TacticModel $tactics
     */
    public function __construct(TacticModel $tactics) {
        $this->tactics = $tactics;
    }

    /**
     * @param SessionHandle $session
     * @return ViewHttpResponse the home page view
     */
    public function home(SessionHandle $session): ViewHttpResponse {
        $limitNbTactics = 5;
        $lastTactic = $this->tactics->getLast($limitNbTactics, $session->getAccount()->getId());
        return ViewHttpResponse::react("views/Home.tsx", [
            "lastTactics" => $lastTactic
        ]);
        // return ViewHttpResponse::react("views/Home.tsx", []);
    }

    public function homeTwig(SessionHandle $session): ViewHttpResponse {
        return ViewHttpResponse::twig("home.twig", []);
    }

    /**
     * @return ViewHttpResponse account settings page
     */
    public function settings(SessionHandle $session): ViewHttpResponse {
        return ViewHttpResponse::twig("account_settings.twig", []);
    }

    public function disconnect(MutableSessionHandle $session): HttpResponse {
        $session->destroy();
        return HttpResponse::redirect("/");
    }

}
